@@ -57,4 +57,7 @@ gchar *grl_core_keys[] = {
 "GRL_METADATA_KEY_MB_RECORDING_ID",
 "GRL_METADATA_KEY_EPISODE_TITLE",
 "GRL_METADATA_KEY_AUDIO_TRACK",
+"GRL_METADATA_KEY_ALBUM_DISC_NUMBER",
+"GRL_METADATA_KEY_COMPOSER",
+"GRL_METADATA_KEY_ALBUM_ARTIST",
 };
